[
    {
       "id": 1,
       "name": "Johnson, Smith, and Jones Co.",
       "amount": 345.33,
       "Remark": "Pays on time"
    },
    {
       "id": 2,
       "name": "Sam \"Mad Dog\" Smith",
       "amount": 993.44,
       "Remark": ""
    },
    {
       "id": 3,
       "name": "Barney & Company",
       "amount": 0,
       "Remark": "Great to work with\nand always pays with cash."
    },
    {
       "id": 4,
       "name": "Johnson's Automotive",
       "amount": 2344,
       "Remark": ""
    }
 ]